<?php
/**
 * CRUDサンプル: これは学習用のサンプルです。
 * 基本的なCRUD操作ができますが、これをインターネット上に公開するようなことは
 * しないでください。これは悪いPHPです。
 *
 * 実際にはWebアプリケーションフレームワークを使って実装することをおすすめします。
 * これがなぜ悪いPHPであるのか、チームで議論するのもありかもしれませんね。
 *
 * @author Yuya Hamada <youkidearitai@gmail.com>
 */
ini_set("display_errors", "on");
error_reporting(E_ALL);

$mode = isset($_GET["mode"]) ? $_GET["mode"] : 'default';
$modes = array(
    'default', 'add', 'delete', 'update',
);
$sqlite_disk_path = dirname(dirname(__FILE__)) . DIRECTORY_SEPARATOR . 'sqlite' . DIRECTORY_SEPARATOR . 'db.sqlite';

// SQLiteで繋ぐ
try {
    $pdo = new PDO(sprintf("sqlite:%s", $sqlite_disk_path));
} catch (PDOException $pdoErr) {
    trigger_error($pdoErr->getMessage(), E_USER_ERROR);
    exit;
} catch (Exception $e) {
    trigger_error($e->getMessage(), E_USER_ERROR);
    exit;
}

// リクエストにないならエラー
if (!in_array($mode, $modes, true)) {
    header("HTTP/1.0 404 Not Found");
    exit;
}

if ($mode === "add") {
    if (isset($_POST["text"])) {
        $stmt = $pdo->prepare('INSERT INTO crud_sample (text) VALUES(:text)');
        if (!$stmt) {
            trigger_error($pdo->errorCode() . implode(",", $pdo->errorInfo()), E_USER_ERROR);
        }
        $stmt->bindParam(':text', $_POST["text"]);
        $stmt->execute();

        header("Location: /crud_sample.php");
        exit;
    }
?>
    <form method="POST" action="crud_sample.php?mode=add">
    <textarea name="text"></textarea>
    <input type="submit" value="追加">
    </form>
<?php
} else if ($mode === "update") {
    if (isset($_POST["id"]) && isset($_POST["text"])) {
        if (preg_match("/\A[0-9]+\z/", $_POST["id"]) === 1) {
            $stmt = $pdo->prepare('UPDATE crud_sample SET text = :text WHERE id = :id');
            if (!$stmt) {
                trigger_error($pdo->errorCode(), E_USER_ERROR);
            }
            $stmt->bindParam(':id', $_POST["id"]);
            $stmt->bindParam(':text', $_POST["text"]);
            $stmt->execute();

            header("Location: /crud_sample.php");
            exit;
        }
    } else {
        $stmt = $pdo->prepare("SELECT id, text FROM crud_sample WHERE id = :id");
        $value = null;
        if (preg_match("/\A[0-9]+\z/", $_GET["id"]) === 1) {
            $stmt->bindParam(':id', $_GET['id']);
            $stmt->execute();
            $value = $stmt->fetch();
        }
?>

    <form method="POST" action="?mode=update">
    <textarea name="text"><?php echo htmlspecialchars($value["text"], ENT_QUOTES, "UTF-8"); ?></textarea>
    <input type="hidden" name="id" value="<?php echo htmlspecialchars($value["id"], ENT_QUOTES, "UTF-8"); ?>">
    <input type="submit" value="適用">
    </form>
<?php
    }
} else if ($mode === "delete") {
    if (isset($_GET["id"])) {
        if (preg_match("/\A[0-9]+\z/", $_GET["id"]) === 1) {
            $stmt = $pdo->prepare('DELETE FROM crud_sample WHERE id = :id');
            if (!$stmt) {
                trigger_error($pdo->errorCode(), E_USER_ERROR);
            }
            $stmt->bindParam(':id', $_GET["id"]);
            $stmt->execute();

            header("Location: /crud_sample.php");
            exit;
        }
    }
} else {
    // listを表示する
    $conn = $pdo->query("SELECT id, text FROM crud_sample ORDER BY id DESC");
    ?><table>
    <tr>
    <th>id</th>
    <th>テキスト</th>
    <th>編集</th>
    <th>削除</th>
    </tr>
    <?php
    foreach ($conn as $row) {
    ?><tr>
        <td><?php echo htmlspecialchars($row["id"], ENT_QUOTES, "UTF-8"); ?></td>
        <td><?php echo htmlspecialchars($row["text"], ENT_QUOTES, "UTF-8"); ?></td>
        <td><a href="?mode=update&id=<?php echo htmlspecialchars($row["id"], ENT_QUOTES, "UTF-8"); ?>">編集</a></td>
        <td><a href="?mode=delete&id=<?php echo htmlspecialchars($row["id"], ENT_QUOTES, "UTF-8"); ?>">削除</a></td>
    </tr>
    <?php
        }
    ?>
    </table>
    <p><a href="?mode=add">追加</a></p>

<?php }
